@@ -50,8 +50,9 @@ get_Layout <- function(
 
     if(layout == "empty") {
 
-      # empty layout definition -------------------------------------------------
       layout = list(
+        
+        ## empty Abanico plot -------------------------------------------------
         abanico = list(
           font.type = list(
             main    = character(1),
@@ -69,6 +70,7 @@ get_Layout <- function(
             stats   = character(1), # optionally vector
             legend  = character(1) # optionally vector
           ),
+          
           font.size = list(
             main    = numeric(1),
             xlab1   = numeric(1),
@@ -86,6 +88,7 @@ get_Layout <- function(
             stats   = numeric(1), # optionally vector
             legend  = numeric(1)  # optionally vector
           ),
+          
           font.deco = list(
             main    = character(1),
             xlab1   = character(1),
@@ -103,6 +106,7 @@ get_Layout <- function(
             stats   = character(1), # optionally vector
             legend  = character(1) # optionally vector
           ),
+          
           colour = list(
             main    = numeric(1), # plot title colour
             xlab1   = numeric(1), # left x-axis label colour
@@ -133,6 +137,7 @@ get_Layout <- function(
             grid.minor = numeric(1),
             border     = numeric(1),
             background = numeric(1)),
+          
           dimension = list(
             figure.width    = numeric(1), # figure width in mm
             figure.height   = numeric(1), # figure height in mm
@@ -157,9 +162,10 @@ get_Layout <- function(
             mtext           = numeric(1), # line height in %
             summary.line    = numeric(1) # line height in %
           )),
+        
+        ## empty KDE plot -----------------------------------------------------
         kde = list(
           font.type = list(
-            ## run font_import() when using user-defined fonts for the first time
             main   = character(1),
             xlab   = character(1),
             ylab1  = character(1),
@@ -170,6 +176,7 @@ get_Layout <- function(
             stats  = character(1), # optionally vector
             legend = character(1) # optionally vector
           ),
+          
           font.size = list(
             main   = numeric(1),
             xlab   = numeric(1),
@@ -181,6 +188,7 @@ get_Layout <- function(
             stats  = numeric(1), # optionally vector
             legend = numeric(1) # optionally vector
           ),
+          
           font.deco = list(
             main   = character(1),
             xlab   = character(1),
@@ -192,6 +200,7 @@ get_Layout <- function(
             stats  = character(1), # optionally vector
             legend = character(1) # optionally vector
           ),
+          
           colour = list(
             main   = numeric(1), # plot title colour
             xlab   = numeric(1), # x-axis label colour
@@ -203,19 +212,17 @@ get_Layout <- function(
             box    = numeric(1), # plot frame box line colour
             mtext  = numeric(1), # subheader text colour
             stats  = numeric(1), # statistic summary colour
-            kde.line        = numeric(1), # KDE line colour
-            kde.fill        = numeric(1), # KDE fill colour
-            value.dot       = numeric(1), # De value dot colour
-            value.bar       = numeric(1), # De value error bar colour
-            value.rug       = numeric(1), # De value rug colour
-            mean            = numeric(1), # mean line colour
-            median          = numeric(1), # median line colour
-            mean.weighted   = numeric(1), # weighted mean line colour
-            median.weighted = numeric(1), # weighted median line colour
-            kdemax          = numeric(1), # KDE max line colour
-            poly.line       = numeric(1), # polygon line colour
-            poly.fill       = numeric(1), # polygon fill colour
-            background      = numeric(1)),
+            kde.line        = numeric(1),  # KDE line colour
+            kde.fill        = numeric(1),  # KDE fill colour
+            value.dot       = numeric(1),  # De value dot colour
+            value.bar       = numeric(1),  # De value error bar colour
+            value.rug       = numeric(1),  # De value rug colour
+            boxplot.line    = numeric(1), # boxplot line colour
+            boxplot.fill    = numeric(1), # boxplot fill colour
+            mean.line       = numeric(1),  # mean line colour
+            sd.bar          = numeric(1),  # sd-line colour
+            background      = numeric(1)), # background colour
+          
           dimension = list(
             figure.width    = numeric(1), # figure width in mm
             figure.height   = numeric(1), # figure height in mm
@@ -236,8 +243,9 @@ get_Layout <- function(
       )
     } else if(layout == "default") {
 
-      # default layout definition -----------------------------------------------
       layout = list(
+        
+        ## default Abanico plot -----------------------------------------------
         abanico = list(
           font.type = list(
             main    = "",
@@ -255,6 +263,7 @@ get_Layout <- function(
             stats   = "", # optionally vector
             legend  = "" # optionally vector
           ),
+          
           font.size = list(
             main    = 12,
             xlab1   = 12,
@@ -272,6 +281,7 @@ get_Layout <- function(
             stats   = 10, # optionally vector
             legend  = 10 # optionally vector
           ),
+          
           font.deco = list(
             main    = "bold",
             xlab1   = "normal",
@@ -289,6 +299,7 @@ get_Layout <- function(
             stats   = "normal", # optionally vector
             legend  = "normal" # optionally vector
           ),
+          
           colour = list(
             main    = 1, # plot title colour
             xlab1   = 1, # left x-axis label colour
@@ -319,6 +330,7 @@ get_Layout <- function(
             grid.minor = "none",
             border     = 1,
             background = NA),
+          
           dimension = list(
             figure.width    = "auto", # figure width in mm
             figure.height   = "auto", # figure height in mm
@@ -343,9 +355,10 @@ get_Layout <- function(
             mtext           = 100, # line height in %
             summary.line    = 100 # line height in %
           )),
+        
+        ## default KDE plot ---------------------------------------------------
         kde = list(
           font.type = list(
-            ## run font_import() when using user-defined fonts for the first time
             main   = "",
             xlab   = "",
             ylab1  = "",
@@ -356,6 +369,7 @@ get_Layout <- function(
             stats  = "", # optionally vector
             legend = "" # optionally vector
           ),
+          
           font.size = list(
             main   = 14,
             xlab   = 12,
@@ -367,6 +381,7 @@ get_Layout <- function(
             stats  = 12, # optionally vector
             legend = 12 # optionally vector
           ),
+          
           font.deco = list(
             main   = "bold",
             xlab   = "normal",
@@ -378,6 +393,7 @@ get_Layout <- function(
             stats  = "normal", # optionally vector
             legend = "normal" # optionally vector
           ),
+          
           colour = list(
             main   = 1, # plot title colour
             xlab   = 1, # x-axis label colour
@@ -387,24 +403,22 @@ get_Layout <- function(
             ytck1  = 1, # primary y-axis tick colour
             ytck2  = 1, # secondary y-axis tick colour
             box    = 1, # plot frame box line colour
-            mtext  = 1, # subheader text colour
-            stats  = "#2062B3", # statistic summary colour
-            kde.line        = "#2062B3", # KDE line colour
-            kde.fill        = "none", # KDE fill colour
+            mtext  = 2, # subheader text colour
+            stats  = 1, # statistic summary colour
+            kde.line        = 1, # KDE line colour
+            kde.fill        = NULL, # KDE fill colour
             value.dot       = 1, # De value dot colour
             value.bar       = 1, # De value error bar colour
             value.rug       = 1, # De value rug colour
-            mean   = 1, # mean line colour
-            median = 1, # median line colour
-            mean.weighted   = 1, # weighted mean line colour
-            median.weighted = 1, # weighted median line colour
-            kdemax = 1, # KDE max line colour
-            poly.line       = NA, # polygon line colour
-            poly.fill       = "grey80", # polygon fill colour
-            background      = NULL),
+            boxplot.line    = 1, # boxplot line colour
+            boxplot.fill    = NULL, # boxplot fill colour
+            mean.point       = 1, # mean line colour
+            sd.line          = 1, # sd bar colour
+            background      = NULL), # background colour
+          
           dimension = list(
-            figure.width    = 50, # figure width in mm
-            figure.height   = 50, # figure height in mm
+            figure.width    = "auto", # figure width in mm
+            figure.height   = "auto", # figure height in mm
             margin = c(10, 10, 10, 10), # margin sizes in mm
             main.line       = 100, # line height in %
             xlab.line       = 100, # line height in %
@@ -422,8 +436,9 @@ get_Layout <- function(
       )
     } else if(layout == "journal") {
 
-      # journal layout definition -----------------------------------------------
       layout = list(
+        
+        ## journal Abanico plot -----------------------------------------------
         abanico = list(
           font.type = list(
             main    = "",
@@ -441,6 +456,7 @@ get_Layout <- function(
             stats   = "", # optionally vector
             legend  = "" # optionally vector
           ),
+          
           font.size = list(
             main    = 8,
             xlab1   = 7,
@@ -458,6 +474,7 @@ get_Layout <- function(
             stats   = 6, # optionally vector
             legend  = 6 # optionally vector
           ),
+          
           font.deco = list(
             main    = "bold",
             xlab1   = "normal",
@@ -475,6 +492,7 @@ get_Layout <- function(
             stats   = "normal", # optionally vector
             legend  = "normal" # optionally vector
           ),
+          
           colour = list(
             main    = 1, # plot title colour
             xlab1   = 1, # left x-axis label colour
@@ -505,6 +523,7 @@ get_Layout <- function(
             grid.minor = "none",
             border     = 1,
             background = NA),
+          
           dimension = list(
             figure.width    = 100, # figure width in mm
             figure.height   = 100, # figure height in mm
@@ -530,9 +549,10 @@ get_Layout <- function(
             summary.line    = 70, # line height in %
             pch             = 50  # point size in %
           )),
+        
+        ## journal KDE plot ---------------------------------------------------
         kde = list(
           font.type = list(
-            ## run font_import() when using user-defined fonts for the first time
             main   = "",
             xlab   = "",
             ylab1  = "",
@@ -543,17 +563,19 @@ get_Layout <- function(
             stats  = "", # optionally vector
             legend = "" # optionally vector
           ),
+          
           font.size = list(
-            main   = 14,
-            xlab   = 12,
-            ylab1  = 12,
-            ylab2  = 12,
-            xtck   = 12,
-            ytck1  = 12,
-            ytck2  = 12,
-            stats  = 12, # optionally vector
-            legend = 12 # optionally vector
+            main   = 8,
+            xlab   = 7,
+            ylab1  = 7,
+            ylab2  = 7,
+            xtck   = 7,
+            ytck1  = 7,
+            ytck2  = 7,
+            stats  = 7,
+            legend = 7
           ),
+          
           font.deco = list(
             main   = "bold",
             xlab   = "normal",
@@ -565,6 +587,7 @@ get_Layout <- function(
             stats  = "normal", # optionally vector
             legend = "normal" # optionally vector
           ),
+          
           colour = list(
             main   = 1, # plot title colour
             xlab   = 1, # x-axis label colour
@@ -577,38 +600,40 @@ get_Layout <- function(
             mtext  = 1, # subheader text colour
             stats  = "#2062B3", # statistic summary colour
             kde.line        = "#2062B3", # KDE line colour
-            kde.fill        = "none", # KDE fill colour
+            kde.fill        = NULL, # KDE fill colour
             value.dot       = 1, # De value dot colour
             value.bar       = 1, # De value error bar colour
             value.rug       = 1, # De value rug colour
-            mean   = 1, # mean line colour
-            median = 1, # median line colour
-            mean.weighted   = 1, # weighted mean line colour
-            median.weighted = 1, # weighted median line colour
-            kdemax = 1, # KDE max line colour
-            poly.line       = NA, # polygon line colour
-            poly.fill       = "grey80", # polygon fill colour
+            boxplot.line    = 1, # boxplot line colour
+            boxplot.fill    = NULL, # boxplot fill colour
+            mean.line       = adjustcolor(col = 1, 
+                                          alpha.f = 0.4), # mean line colour
+            sd.bar          = adjustcolor(col = 1, 
+                                          alpha.f = 0.4), # sd bar colour
             background      = NULL),
+          
           dimension = list(
-            figure.width    = 50, # figure width in mm
-            figure.height   = 50, # figure height in mm
+            figure.width    = 80, # figure width in mm
+            figure.height   = 80, # figure height in mm
             margin = c(10, 10, 10, 10), # margin sizes in mm
-            main.line       = 100, # line height in %
-            xlab.line       = 100, # line height in %
-            ylab1.line      = 100, # line height in %
-            ylab2.line      = 100, # line height in %
-            xtck.line       = 100, # line height in %
-            ytck1.line      = 100, # line height in %
-            ytck2.line      = 100, # line height in %
-            xtcl            = 100, # tick length in %
-            ytcl1           = 100, # tick length in %
-            ytcl2           = 100, # tick length in %
-            stats.line      = 100 # line height in %
+            main.line       = 70, # line height in %
+            xlab.line       = 30, # line height in %
+            ylab1.line      = 40, # line height in %
+            ylab2.line      = 30, # line height in %
+            xtck.line       = 50, # line height in %
+            ytck1.line      = 65, # line height in %
+            ytck2.line      = 50, # line height in %
+            xtcl            = 50, # tick length in %
+            ytcl1           = 20, # tick length in %
+            ytcl2           = 50, # tick length in %
+            stats.line      = 70 # line height in %
           )
         )
       )
     } else {
-      stop("Layout definition not supported!")
+      warning("Layout definition not supported! Default layout is used.")
+      
+      layout <- get_Layout(layout = "default")
     }
   } else if(is.list(layout) == TRUE) {
 
@@ -619,3 +644,4 @@ get_Layout <- function(
   ## return layout parameters
   return(layout)
 }
+
