@@ -18,8 +18,11 @@
 #' @seealso
 #' \code{\linkS4class{Risoe.BINfileData}}
 #' @keywords utilities
-#' 
+#'
 #' @export
-setGeneric("set_Risoe.BINfileData", function(METADATA, DATA, .RESERVED) {
-  standardGeneric("set_Risoe.BINfileData")
-})
+setGeneric("set_Risoe.BINfileData",
+  function(METADATA = data.frame(), DATA = list(), .RESERVED = list()) {
+    standardGeneric("set_Risoe.BINfileData")
+  },
+  package = "Luminescence"
+)
